@@ -333,13 +333,15 @@ class Database(core.Construct):
                 storage_encryption_key=encryption_key,
             )
 
-            self._instance.node.find_child("Resource").add_property_override(
+            # Conditionally create an instance from a snapshot
+            if use_snapshot:
+                self._instance.node.find_child("Resource").add_property_override(
                 "DBSnapshotIdentifier", database_snapshot_id
-            )
-            # While creating an RDS from a snapshot, MasterUsername cannot be specified
-            self._instance.node.find_child("Resource").add_property_override(
-                "MasterUsername", None
-            )
+                )
+                # While creating an RDS from a snapshot, MasterUsername cannot be specified
+                self._instance.node.find_child("Resource").add_property_override(
+                    "MasterUsername", None
+                )
 
             self._instance.add_rotation_single_user(
                 automatically_after=core.Duration.days(30)
