@@ -1121,6 +1121,22 @@ class Microservice(core.Construct):
             ROOT_VOLUME_SIZE,
         )
         block_devices = _asg.BlockDevice(device_name="/dev/xvda", volume=volume)
+        
+        rolling_update_configuration = _asg.RollingUpdateConfiguration(
+                max_batch_size=1,
+                min_instances_in_service=2 if is_ha else 0,
+                min_successful_instances_percent=100,
+                pause_time=core.Duration.minutes(30),
+                # ASG best practice https://aws.amazon.com/premiumsupport/knowledge-center/auto-scaling-group-rolling-updates/
+                suspend_processes=[
+                    _asg.ScalingProcess.HEALTH_CHECK,
+                    _asg.ScalingProcess.REPLACE_UNHEALTHY,
+                    _asg.ScalingProcess.AZ_REBALANCE,
+                    _asg.ScalingProcess.ALARM_NOTIFICATION,
+                    _asg.ScalingProcess.SCHEDULED_ACTIONS,
+                ],
+                wait_on_resource_signals=is_ha,
+            )
 
         self._asg = _asg.AutoScalingGroup(
             self,
@@ -1141,24 +1157,9 @@ class Microservice(core.Construct):
             resource_signal_timeout=core.Duration.minutes(30),
             # block_devices=[block_devices],
             update_type=_asg.UpdateType.ROLLING_UPDATE,
-            rolling_update_configuration=_asg.RollingUpdateConfiguration(
-                max_batch_size=1,
-                min_instances_in_service=2 if is_ha else 1,
-                min_successful_instances_percent=100,
-                pause_time=core.Duration.minutes(30),
-                # ASG best practice https://aws.amazon.com/premiumsupport/knowledge-center/auto-scaling-group-rolling-updates/
-                suspend_processes=[
-                    _asg.ScalingProcess.HEALTH_CHECK,
-                    _asg.ScalingProcess.REPLACE_UNHEALTHY,
-                    _asg.ScalingProcess.AZ_REBALANCE,
-                    _asg.ScalingProcess.ALARM_NOTIFICATION,
-                    _asg.ScalingProcess.SCHEDULED_ACTIONS,
-                ],
-                wait_on_resource_signals=True,
-            ),
+            rolling_update_configuration=rolling_update_configuration,
         )
         
-
         ags_config = self._asg.node.find_child("LaunchConfig")
         ags_config.add_property_override(
             property_path="BlockDeviceMappings",
