@@ -59,7 +59,8 @@ class ServiceUserForIAC(core.Construct):
         # S3 buckets 
         s3_buckets = [
             "arn:aws:s3:::" + app_name + "*", 
-            "arn:aws:s3:::awsserverlessrepo-changesets-*"
+            "arn:aws:s3:::awsserverlessrepo-changesets-*",
+            "arn:aws:s3:::cdktoolkit*",
             ]
 
         if s3_code_bucket_name is not None:
